diff --git a/include/trace-cmd/trace-cmd.h b/include/trace-cmd/trace-cmd.h
index 9d9a61d3..75352309 100644
--- a/include/trace-cmd/trace-cmd.h
+++ b/include/trace-cmd/trace-cmd.h
@@ -26,7 +26,7 @@ tracecmd_read_at(struct tracecmd_input *handle, unsigned long long offset,
 		 int *cpu);
 void tracecmd_free_record(struct tep_record *record);
 
-struct tep_handle *tracecmd_get_pevent(struct tracecmd_input *handle);
+struct tep_handle *tracecmd_get_tep(struct tracecmd_input *handle);
 unsigned long long tracecmd_get_traceid(struct tracecmd_input *handle);
 int tracecmd_get_guest_cpumap(struct tracecmd_input *handle,
 			      unsigned long long trace_id,
diff --git a/kernel-shark/src/libkshark.c b/kernel-shark/src/libkshark.c
index 9823ccc9..8f5dcb00 100644
--- a/kernel-shark/src/libkshark.c
+++ b/kernel-shark/src/libkshark.c
@@ -155,7 +155,7 @@ bool kshark_open(struct kshark_context *kshark_ctx, const char *file)
 	}
 
 	kshark_ctx->handle = handle;
-	kshark_ctx->pevent = tracecmd_get_pevent(handle);
+	kshark_ctx->pevent = tracecmd_get_tep(handle);
 
 	kshark_ctx->advanced_event_filter =
 		tep_filter_alloc(kshark_ctx->pevent);
diff --git a/lib/trace-cmd/trace-blk-hack.c b/lib/trace-cmd/trace-blk-hack.c
index 4f5953ad..2a05cf98 100644
--- a/lib/trace-cmd/trace-blk-hack.c
+++ b/lib/trace-cmd/trace-blk-hack.c
@@ -39,7 +39,7 @@ int tracecmd_blk_hack(struct tracecmd_input *handle)
 	int l;
 	int r;
 
-	pevent = tracecmd_get_pevent(handle);
+	pevent = tracecmd_get_tep(handle);
 
 	/*
 	 * Unfortunately, the TRACE_BLK has changed a bit.
diff --git a/lib/trace-cmd/trace-ftrace.c b/lib/trace-cmd/trace-ftrace.c
index 03e60eb0..f74f7c2e 100644
--- a/lib/trace-cmd/trace-ftrace.c
+++ b/lib/trace-cmd/trace-ftrace.c
@@ -370,7 +370,7 @@ int tracecmd_ftrace_overrides(struct tracecmd_input *handle,
 
 	finfo->handle = handle;
 
-	pevent = tracecmd_get_pevent(handle);
+	pevent = tracecmd_get_tep(handle);
 
 	tep_register_event_handler(pevent, -1, "ftrace", "function",
 				      function_handler, NULL);
diff --git a/lib/trace-cmd/trace-output.c b/lib/trace-cmd/trace-output.c
index de76e3e7..032c8ff4 100644
--- a/lib/trace-cmd/trace-output.c
+++ b/lib/trace-cmd/trace-output.c
@@ -877,9 +877,9 @@ create_file_fd(int fd, struct tracecmd_input *ihandle,
 
 	/* get endian and page size */
 	if (ihandle) {
-		pevent = tracecmd_get_pevent(ihandle);
+		pevent = tracecmd_get_tep(ihandle);
 		/* Use the pevent of the ihandle for later writes */
-		handle->pevent = tracecmd_get_pevent(ihandle);
+		handle->pevent = tracecmd_get_tep(ihandle);
 		tep_ref(pevent);
 		if (tep_is_file_bigendian(pevent))
 			buf[0] = 1;
@@ -1433,9 +1433,9 @@ struct tracecmd_output *tracecmd_get_output_handle_fd(int fd)
 	handle->fd = fd;
 
 	/* get endian and page size */
-	pevent = tracecmd_get_pevent(ihandle);
+	pevent = tracecmd_get_tep(ihandle);
 	/* Use the pevent of the ihandle for later writes */
-	handle->pevent = tracecmd_get_pevent(ihandle);
+	handle->pevent = tracecmd_get_tep(ihandle);
 	tep_ref(pevent);
 	handle->page_size = tracecmd_page_size(ihandle);
 	list_head_init(&handle->options);
diff --git a/tracecmd/trace-hist.c b/tracecmd/trace-hist.c
index 76e8cae2..ea9b2bef 100644
--- a/tracecmd/trace-hist.c
+++ b/tracecmd/trace-hist.c
@@ -933,7 +933,7 @@ static void print_chains(struct tep_handle *pevent)
 
 static void do_trace_hist(struct tracecmd_input *handle)
 {
-	struct tep_handle *pevent = tracecmd_get_pevent(handle);
+	struct tep_handle *pevent = tracecmd_get_tep(handle);
 	struct tep_record *record;
 	struct tep_event *event;
 	int cpus;
diff --git a/tracecmd/trace-mem.c b/tracecmd/trace-mem.c
index c6cc7dee..2eb75a00 100644
--- a/tracecmd/trace-mem.c
+++ b/tracecmd/trace-mem.c
@@ -461,7 +461,7 @@ static void print_list(void)
 
 static void do_trace_mem(struct tracecmd_input *handle)
 {
-	struct tep_handle *pevent = tracecmd_get_pevent(handle);
+	struct tep_handle *pevent = tracecmd_get_tep(handle);
 	struct tep_record *record;
 	struct tep_event *event;
 	int missed_events = 0;
diff --git a/tracecmd/trace-profile.c b/tracecmd/trace-profile.c
index b82110e6..e3a75143 100644
--- a/tracecmd/trace-profile.c
+++ b/tracecmd/trace-profile.c
@@ -1267,7 +1267,7 @@ static int handle_sched_wakeup_event(struct handle_data *h,
 void trace_init_profile(struct tracecmd_input *handle, struct hook_list *hook,
 			int global)
 {
-	struct tep_handle *pevent = tracecmd_get_pevent(handle);
+	struct tep_handle *pevent = tracecmd_get_tep(handle);
 	struct tep_format_field **fields;
 	struct handle_data *h;
 	struct event_data *event_data;
diff --git a/tracecmd/trace-read.c b/tracecmd/trace-read.c
index 11293bc8..d07f4efe 100644
--- a/tracecmd/trace-read.c
+++ b/tracecmd/trace-read.c
@@ -150,7 +150,7 @@ enum time_fmt {
 
 static const char *time_format(struct tracecmd_input *handle, enum time_fmt tf)
 {
-	struct tep_handle *tep = tracecmd_get_pevent(handle);
+	struct tep_handle *tep = tracecmd_get_tep(handle);
 
 	switch (tf) {
 	case TIME_FMT_LAT:
@@ -171,7 +171,7 @@ static const char *time_format(struct tracecmd_input *handle, enum time_fmt tf)
 static void print_event(struct trace_seq *s, struct tracecmd_input *handle,
 			struct tep_record *record)
 {
-	struct tep_handle *tep = tracecmd_get_pevent(handle);
+	struct tep_handle *tep = tracecmd_get_tep(handle);
 	struct tep_event *event;
 	const char *lfmt = time_format(handle, TIME_FMT_LAT);
 	const char *tfmt = time_format(handle, TIME_FMT_NORMAL);
@@ -481,7 +481,7 @@ static void convert_comm_filter(struct tracecmd_input *handle)
 	if (!comm_list)
 		return;
 
-	pevent = tracecmd_get_pevent(handle);
+	pevent = tracecmd_get_tep(handle);
 
 	/* Seach for comm names and get their pids */
 	for (list = comm_list; list; list = list->next) {
@@ -545,7 +545,7 @@ static void process_filters(struct handle_list *handles)
 	int filters = 0;
 	int ret;
 
-	pevent = tracecmd_get_pevent(handles->handle);
+	pevent = tracecmd_get_tep(handles->handle);
 
 	make_pid_filter(handles->handle);
 
@@ -592,7 +592,7 @@ static void init_wakeup(struct tracecmd_input *handle)
 	if (!show_wakeup)
 		return;
 
-	pevent = tracecmd_get_pevent(handle);
+	pevent = tracecmd_get_tep(handle);
 
 	trace_hash_init(&wakeup_hash, WAKEUP_HASH_SIZE);
 
@@ -829,7 +829,7 @@ void trace_show_data(struct tracecmd_input *handle, struct tep_record *record)
 		return;
 	}
 
-	pevent = tracecmd_get_pevent(handle);
+	pevent = tracecmd_get_tep(handle);
 	event = tep_find_event_by_record(pevent, record);
 	use_trace_clock = tracecmd_get_use_trace_clock(handle);
 
@@ -1028,7 +1028,7 @@ test_stacktrace(struct handle_list *handles, struct tep_record *record,
 				die("Failed to allocate for %d cpus", info->nr_cpus);
 			memset(info->cpus, 0, sizeof(*info->cpus));
 
-			pevent = tracecmd_get_pevent(h->handle);
+			pevent = tracecmd_get_tep(h->handle);
 			event = tep_find_event_by_name(pevent, "ftrace",
 						       "kernel_stack");
 			if (event)
@@ -1044,7 +1044,7 @@ test_stacktrace(struct handle_list *handles, struct tep_record *record,
 	}
 
 	handle = handles->handle;
-	pevent = tracecmd_get_pevent(handle);
+	pevent = tracecmd_get_tep(handle);
 
 	for (info = infos; info; info = info->next)
 		if (info->handles == handles)
@@ -1087,7 +1087,7 @@ static struct tep_record *get_next_record(struct handle_list *handles)
 	if (handles->done)
 		return NULL;
 
-	pevent = tracecmd_get_pevent(handles->handle);
+	pevent = tracecmd_get_tep(handles->handle);
 
 	do {
 		if (filter_cpus) {
@@ -1247,7 +1247,7 @@ static void read_data_info(struct list_head *handle_list, enum output_type otype
 		}
 
 		/* Find the kernel_stacktrace if available */
-		pevent = tracecmd_get_pevent(handles->handle);
+		pevent = tracecmd_get_tep(handles->handle);
 		event = tep_find_event_by_name(pevent, "ftrace", "kernel_stack");
 		if (event)
 			stacktrace_id = event->id;
@@ -1795,7 +1795,7 @@ void trace_report (int argc, char **argv)
 		else if (ts2secs)
 			tracecmd_set_ts2secs(handle, ts2secs);
 
-		pevent = tracecmd_get_pevent(handle);
+		pevent = tracecmd_get_tep(handle);
 
 		if (nanosec)
 			tep_set_flag(pevent, TEP_NSEC_OUTPUT);
diff --git a/tracecmd/trace-split.c b/tracecmd/trace-split.c
index f6ab970b..9d347b36 100644
--- a/tracecmd/trace-split.c
+++ b/tracecmd/trace-split.c
@@ -87,7 +87,7 @@ static int write_record(struct tracecmd_input *handle,
 
 	page = cpu_data->page;
 
-	pevent = tracecmd_get_pevent(handle);
+	pevent = tracecmd_get_tep(handle);
 
 	ptr = page + cpu_data->index;
 
@@ -191,7 +191,7 @@ static int parse_cpu(struct tracecmd_input *handle,
 
 	long_size = tracecmd_long_size(handle);
 	page_size = tracecmd_page_size(handle);
-	pevent = tracecmd_get_pevent(handle);
+	pevent = tracecmd_get_tep(handle);
 
 	/* Force new creation of first page */
 	if (percpu) {

diff --git a/lib/trace-cmd/trace-input.c b/lib/trace-cmd/trace-input.c
index e57492e9..9dda0dd5 100644
--- a/lib/trace-cmd/trace-input.c
+++ b/lib/trace-cmd/trace-input.c
@@ -3776,10 +3776,10 @@ int tracecmd_cpus(struct tracecmd_input *handle)
 }
 
 /**
  * tracecmd_get_pevent - return the pevent handle
  * @handle: input handle for the trace.dat file
  */
-struct tep_handle *tracecmd_get_pevent(struct tracecmd_input *handle)
+struct tep_handle *tracecmd_get_tep(struct tracecmd_input *handle)
 {
 	return handle->pevent;
 }
@@ -3776,10 +3776,10 @@ int tracecmd_cpus(struct tracecmd_input *handle)
 
 /**
- * tracecmd_get_pevent - return the pevent handle
+ * tracecmd_get_tep - return the tep handle
  * @handle: input handle for the trace.dat file
  */